@@ -1,12 +1,13 @@
 use strict;
 use warnings;
-package B::Hooks::Parser; # git description: v0.14-5-g2da17d9
+package B::Hooks::Parser; # git description: v0.17-5-g581a8c0
 # ABSTRACT: Interface to perl's parser variables
+# KEYWORDS: perl internals API parser hooks modify
 
 use B::Hooks::OP::Check;
 use parent qw/DynaLoader/;
 
-our $VERSION = '0.15'; # TRIAL
+our $VERSION = '0.18'; # TRIAL
 
 sub dl_load_flags { 0x01 }
 
@@ -41,7 +42,7 @@ B::Hooks::Parser - Interface to perl's parser variables
 
 =head1 VERSION
 
-version 0.15
+version 0.18
 
 =head1 DESCRIPTION
 
@@ -117,6 +118,11 @@ Note: may be implemented as a macro.
 
 =head2 C<void hook_parser_clear_lex_stuff (pTHX)>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=B-Hooks-Parser>
+(or L<bug-B-Hooks-Parser@rt.cpan.org|mailto:bug-B-Hooks-Parser@rt.cpan.org>).
+
 =head1 AUTHOR
 
 Florian Ragwitz <rafl@debian.org>
@@ -149,7 +155,7 @@ Liu Kang-min <gugod@gugod.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2008 by Florian Ragwitz.
 
